# platformdirs

`platformdirs` is a small Python module for determining appropriate platform-specific directories for applications. This is useful for finding where to store user data, configuration files, caches, and logs.

The library is a fork of the `appdirs` package and is maintained by the `tox-dev` team.

## Key Links

- **GitHub Repository:** [https://github.com/tox-dev/platformdirs](https://github.com/tox-dev/platformdirs)
- **Documentation:** [https://platformdirs.readthedocs.io/en/latest/](https://platformdirs.readthedocs.io/en/latest/)
- **PyPI Page:** [https://pypi.org/project/platformdirs/](https://pypi.org/project/platformdirs/)
